hgkw/keyword.py
changeset 597 795a95d7dc61
parent 596 2de4e2be005c
child 600 b40e7861defd
--- a/hgkw/keyword.py	Mon Jun 29 18:37:08 2009 +0200
+++ b/hgkw/keyword.py	Mon Jun 29 18:37:08 2009 +0200
@@ -359,16 +359,19 @@
     _kwfwrite(ui, repo, True, *pats, **opts)
 
 def files(ui, repo, *pats, **opts):
-    '''print filenames configured for keyword expansion
+    '''show files configured for keyword expansion
 
     Check which filenames in the working directory are matched by the
     [keyword] configuration patterns.
 
     Useful to prevent inadvertent keyword expansion and to speed up
     execution by including only filenames that are actual candidates
     for expansion.
 
-    Use -u/--untracked to display untracked filenames as well.
+    See "hg help keyword" on how to construct patterns both for
+    inclusion and exclusion of files.
+
+    Use -u/--untracked to list untracked files as well.
 
     With -a/--all and -v/--verbose the codes used to show the status
     of files are:
@@ -359,16 +359,19 @@
 
-    Check which filenames in the working directory are matched by the
+    List which files in the working directory are matched by the
     [keyword] configuration patterns.
 
@@ -359,16 +359,19 @@
 
     Useful to prevent inadvertent keyword expansion and to speed up
-    execution by including only filenames that are actual candidates
+    execution by including only files that are actual candidates
     for expansion.
 